<?php

namespace Drupal\homebox\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBundleBase;

/**
 * Defines the Homebox entity.
 *
 * @ConfigEntityType(
 *   id = "homebox",
 *   label = @Translation("Homebox"),
 *   handlers = {
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" = "Drupal\homebox\HomeboxListBuilder",
 *     "form" = {
 *       "settings" = "Drupal\homebox\Form\HomeboxSettingsForm",
 *       "add" = "Drupal\homebox\Form\HomeboxForm",
 *       "edit" = "Drupal\homebox\Form\HomeboxForm",
 *       "delete" = "Drupal\homebox\Form\HomeboxDeleteForm"
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\homebox\HomeboxHtmlRouteProvider",
 *     },
 *   },
 *   config_prefix = "homebox",
 *   admin_permission = "administer homebox",
 *   bundle_of = "homebox_layout",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid",
 *     "restrictedRoles" = "restrictedRoles",
 *     "layoutId" = "layoutId",
 *     "blocks" = "blocks",
 *     "dashboardPageEnabled" = "dashboardPageEnabled",
 *     "dashboardUserTabEnabled" = "dashboardUserTabEnabled",
 *     "customPagePath" = "customPagePath",
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "uuid",
 *     "restrictedRoles",
 *     "layoutId",
 *     "blocks",
 *     "dashboardPageEnabled",
 *     "dashboardUserTabEnabled",
 *     "customPagePath",
 *   },
 *   links = {
 *     "settings-form" = "/admin/structure/homebox/{homebox}/settings",
 *     "canonical" = "/admin/structure/homebox/{homebox}",
 *     "add-form" = "/admin/structure/homebox/add",
 *     "add-page" = "/admin/content/homebox/homebox/add",
 *     "edit-form" = "/admin/structure/homebox/{homebox}/edit",
 *     "delete-form" = "/admin/structure/homebox/{homebox}/delete",
 *     "collection" = "/admin/structure/homebox"
 *   }
 * )
 */
class Homebox extends ConfigEntityBundleBase implements HomeboxInterface {

  /**
   * The Homebox ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The Homebox label.
   *
   * @var string
   */
  protected $label;

  /**
   * List of user role IDs to deny access to use this homebox.
   *
   * @var array
   */
  protected $restrictedRoles = [];

  /**
   * The layout ID.
   *
   * @var string
   */
  protected $layoutId;

  /**
   * Enabled blocks.
   *
   * @var array
   */
  protected $blocks;

  /**
   * Whether or not this entity has a custom page.
   *
   * @var bool
   */
  protected $dashboardPageEnabled;

  /**
   * Whether or not this entity has a custom page.
   *
   * @var bool
   */
  protected $dashboardUserTabEnabled;

  /**
   * The homebox path alias.
   *
   * @var string
   */
  protected $customPagePath;

  /**
   * {@inheritdoc}
   */
  public function getRestrictedRoles() {
    return $this->restrictedRoles;
  }

  /**
   * {@inheritdoc}
   */
  public function getLayoutId() {
    return $this->layoutId;
  }

  /**
   * {@inheritdoc}
   */
  public function getBlocks() {
    return $this->blocks;
  }

  /**
   * {@inheritdoc}
   */
  public function getDashboardPageEnabled() {
    return $this->dashboardPageEnabled;
  }

  /**
   * {@inheritdoc}
   */
  public function getDashboardUserTabEnabled() {
    return $this->dashboardUserTabEnabled;
  }

  /**
   * {@inheritDoc}
   */
  public function getCustomPagePath() {
    return $this->customPagePath;
  }

  /**
   * {@inheritdoc}
   */
  public function setRestrictedRoles(array $restrictedRoles) {
    $this->restrictedRoles = $restrictedRoles;

    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function setBlocks(array $blocks) {
    $this->blocks = $blocks;

    return $this;
  }

}
