<?php

namespace Drupal\homebox\Entity;

use Drupal\Core\Config\Entity\ConfigEntityInterface;

/**
 * Provides an interface for defining Homebox entities.
 */
interface HomeboxInterface extends ConfigEntityInterface {

  /**
   * Gets the list of user role IDs.
   *
   * @return array
   *   List of user role IDs.
   */
  public function getRestrictedRoles();

  /**
   * Gets the layout ID.
   *
   * @return string
   *   Layout ID.
   */
  public function getLayoutId();

  /**
   * Gets the enabled blocks.
   *
   * @return mixed
   *   Enabled blocks.
   */
  public function getBlocks();

  /**
   * Returns if there is a custom page enabled for this entity.
   */
  public function getDashboardPageEnabled();

  /**
   * Returns if there is a user tab page enabled for this entity.
   */
  public function getDashboardUserTabEnabled();

  /**
   * Returns the custom page path.
   */
  public function getCustomPagePath();

  /**
   * Sets the list of user role IDs.
   *
   * @param array $roles
   *   The list of user role IDs.
   *
   * @return $this
   */
  public function setRestrictedRoles(array $roles);

  /**
   * Sets the list of layouted blocks.
   *
   * @param array $blocks
   *   Gets the layouted blocks.
   *
   * @return $this
   */
  public function setBlocks(array $blocks);

}
