<?php

namespace Drupal\homebox\EventSubscriber;

use Drupal\Core\Routing\RouteSubscriberBase;
use Drupal\Core\Routing\RoutingEvents;
use Symfony\Component\Routing\Route;
use Symfony\Component\Routing\RouteCollection;

/**
 * Homebox event subscriber.
 */
class HomeboxRouteSubscriber extends RouteSubscriberBase {

  /**
   * An entity type manager object.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * {@inheritDoc}
   */
  public function __construct($entityTypeManager) {
    $this->entityTypeManager = $entityTypeManager;
  }

  /**
   * Alters route.
   *
   * @param \Symfony\Component\Routing\RouteCollection $collection
   *   A collection of all the routes.
   */
  protected function alterRoutes(RouteCollection $collection) {
    $homeboxStorage = $this->entityTypeManager->getStorage('homebox');
    /** @var \Drupal\homebox\Entity\HomeboxInterface[] $homeboxes*/
    $homeboxes = $homeboxStorage->loadMultiple();
    foreach ($homeboxes as $homebox) {
      if (!empty($homebox->getCustomPagePath() && $homebox->getDashboardPageEnabled())) {
        $route = new Route(
          $homebox->getCustomPagePath(),
          [
            '_form' => '\Drupal\homebox\Form\HomeboxDashboardPageForm',
            '_title' => $homebox->label(),
            'homebox' => $homebox->id(),
          ],
          // The requirements:
          [
            '_custom_access' => '\Drupal\homebox\Controller\HomeboxController::accessDashboardPage',
          ]
        );
        if (empty($collection->get('homebox.custom_page_route.' . $homebox->id()))) {
          $collection->add('homebox.custom_page_route.' . $homebox->id(), $route);
        }
        else {
          $collection->remove('homebox.custom_page_route.' . $homebox->id());
          $collection->add('homebox.custom_page_route.' . $homebox->id(), $route);
        }
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    // Come after field_ui.
    $events[RoutingEvents::ALTER] = ['onAlterRoutes', -110];
    return $events;
  }

}
