<?php

namespace Drupal\homebox\Form;

use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Entity\EntityConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\CachedDiscoveryClearerInterface;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Builds the form to delete Homebox entities.
 */
class HomeboxDeleteForm extends EntityConfirmFormBase {

  /**
   * Cache clearer service.
   *
   * @var \Drupal\Core\Plugin\CachedDiscoveryClearerInterface
   */
  protected $cacheClearer;

  /**
   * Cache render service.
   *
   * @var \Drupal\Core\Cache\CacheBackendInterface
   */
  protected $cacheRender;

  /**
   * HomeboxDeleteForm constructor.
   *
   * @param \Drupal\Core\Plugin\CachedDiscoveryClearerInterface $plugin_cache_clearer
   *   Plugin Cache Clearer.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache_render
   *   Cache Renderer.
   */
  public function __construct(CachedDiscoveryClearerInterface $plugin_cache_clearer, CacheBackendInterface $cache_render) {
    $this->cacheClearer = $plugin_cache_clearer;
    $this->cacheRender = $cache_render;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    /** @var \Drupal\Core\Plugin\CachedDiscoveryClearerInterface $plugin_cache_clearer */
    $plugin_cache_clearer = $container->get('plugin.cache_clearer');
    /** @var \Drupal\Core\Cache\CacheBackendInterface $cache_render */
    $cache_render = $container->get('cache.render');
    return new static(
      $plugin_cache_clearer,
      $cache_render
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return $this->t('Are you sure you want to delete %name?', ['%name' => $this->entity->label()]);
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('entity.homebox.collection');
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return $this->t('Delete');
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->entity->delete();

    // Clear cache to rebuild tasks links.
    $this->cacheClearer->clearCachedDefinitions();
    $this->cacheRender->invalidateAll();

    $this->messenger()->addMessage(
      $this->t('content @type: deleted @label.',
        [
          '@type' => $this->entity->bundle(),
          '@label' => $this->entity->label(),
        ]
        )
    );

    $form_state->setRedirectUrl($this->getCancelUrl());
  }

}
