<?php

namespace Drupal\Tests\homebox\Functional;

use Drupal\homebox\Entity\Homebox;

/**
 * A Test Helper class for Homebox Tests.
 */
class HomeboxTestHelper {

  /**
   * Creates a homebox entity.
   *
   * @param string $id
   *   The homebox id.
   * @param string $label
   *   The homebox label.
   * @param bool $dashboardPageEnabled
   *   The homebox dashboardPageEnabled variable.
   * @param bool $dashboardUserTabEnabled
   *   The homebox dashboardUserTabEnabled variable.
   * @param array $restrictedRoles
   *   The unallowed homebox access roles.
   * @param string $layoutId
   *   The homebox layout id.
   * @param array $blocks
   *   The homebox blocks.
   * @param string $customPagePath
   *   The homebox custom page path.
   */
  public function createHomebox(string $id, string $label, bool $dashboardPageEnabled = FALSE, bool $dashboardUserTabEnabled = FALSE, array $restrictedRoles = [], string $layoutId = '', array $blocks = [], string $customPagePath = '') {
    $homebox = Homebox::create([
      'id' => $id,
      'label' => $label,
      'restrictedRoles' => $restrictedRoles,
      'layoutId' => $layoutId,
      'blocks' => $blocks,
      'dashboardPageEnabled' => $dashboardPageEnabled,
      'dashboardUserTabEnabled' => $dashboardUserTabEnabled,
      'customPagePath' => $customPagePath,
    ])->save();
    \Drupal::service('router.builder')->rebuild();
    return $homebox;
  }

  /**
   * This function will create a pseudo block array.
   *
   * These pseudo blocks are saved for each homebox entity, see
   * https://www.drupal.org/project/homebox/issues/3266328.
   *
   * @param string $id
   *   The pseudo block id.
   * @param string $title
   *   The pseudo block title.
   * @param int $weight
   *   The pseudo block weight.
   * @param string $region
   *   The pseudo block region.
   * @param bool $status
   *   The pseudo block status.
   */
  public function createPseudoBlock(string $id, string $title, int $weight, string $region, bool $status) {
    return [
      'id' => $id,
      'title' => $title,
      'weight' => $weight,
      'region' => $region,
      'status' => $status,
    ];
  }

}
